//! A common set of types needed for a meaningful use of ez-err.

pub use crate::bail;
pub use crate::core::*;
pub use crate::flc;
pub use crate::slice_ext::*;
